require 'httparty'
require 'json'

module Steward
  class Client
    include HTTParty
    base_uri 'steward.io'

    attr_accessor :api_key

    def initialize(api_key)
      self.api_key = api_key
    end

    def job_started(job)
      notify(job, :start)
    end

    def job_ended(job)
      notify(job, :end)
    end

    def job_failed(job)
      notify(job, :failed)
    end

    def job(job, &block)
      job_started(job)
      block.call
      job_ended(job)
    rescue Exception => e
      job_failed(job)
      raise e
    end

    private

    def notify(job, endpoint)
      response = self.class.get("/j/#{job}/#{endpoint}", headers: { 'X-StewardToken' => api_key })
      JSON.parse(response.body)
    end
  end
end
